@@ -4,6 +4,12 @@ import pandas as pd
 
 
 class ComparisonsMixin(RequestCore):
+    """Comparisons PortalSession mixin
+
+    Mixin for the PortalSession class which contains methods for pipeline related
+    routes.
+    """
+
     def comparisons(self):
         """List comparisons
 
@@ -25,6 +31,7 @@ class ComparisonsMixin(RequestCore):
             "treatment_label",
             "treatment_ids",
             "control_ids",
+            "annotation_id",
         ]
         data = self._post("comparisons/retrieve", expect_data=True)["response"]["data"]
         if data is None:
