@@ -3,6 +3,12 @@ import pandas as pd
 
 
 class ProjectsMixin(RequestCore):
+    """Projects PortalSession mixin
+
+    Mixin for the PortalSession class which contains methods for project related
+    routes.
+    """
+
     def projects(self):
         """List projects
 
