@@ -4,6 +4,12 @@ import pandas as pd
 
 
 class ReferenceSetsMixin(RequestCore):
+    """Reference sets PortalSession mixin
+
+    Mixin for the PortalSession class which contains methods for reference set related
+    routes.
+    """
+
     def reference_sets(self, tag_suffix="_tag_dupl"):
         """List reference sets
 
