@@ -4,6 +4,12 @@ import pandas as pd
 
 
 class SignaturesMixin(RequestCore):
+    """Signatures PortalSession mixin
+
+    Mixin for the PortalSession class which contains methods for signature related
+    routes.
+    """
+
     def signatures(self):
         """List signatures
 
