@@ -7,7 +7,7 @@ import time
 from tqdm import tqdm
 
 
-def timer(func):
+def _timer(func):
     @functools.wraps(func)
     def wrapper_timer(*args, **kwargs):
         tic = time.perf_counter()
@@ -25,7 +25,7 @@ def _single_spaced(x):
 
 
 def _versions(current_version):
-    url = f"https://pypi.org/pypi/insightspy/json"
+    url = "https://pypi.org/pypi/insightspy/json"
     data = json.load(urllib.request.urlopen(url))
     # Get versions on pip
     versions_list = list(data["releases"].keys())
